@@ -2,6 +2,8 @@
  "REFERENCES"
  (lambda ()
    (LaTeX-add-bibitems
+    "Godolphin2007Sarma"
+    "Friedlander1984CramerRaoArma"
     "BrockwellDavis1991"
     "FrancqZakoian2010garch"
     "Li2004diagnostic"
